@@ -1,7 +1,7 @@
 package Complete::Util;
 
-our $DATE = '2015-08-11'; # DATE
-our $VERSION = '0.32'; # VERSION
+our $DATE = '2015-09-03'; # DATE
+our $VERSION = '0.33'; # VERSION
 
 use 5.010001;
 use strict;
@@ -551,7 +551,7 @@ Complete::Util - General completion routine
 
 =head1 VERSION
 
-This document describes version 0.32 of Complete::Util (from Perl distribution Complete-Util), released on 2015-08-11.
+This document describes version 0.33 of Complete::Util (from Perl distribution Complete-Util), released on 2015-09-03.
 
 =head1 DESCRIPTION
 
@@ -560,12 +560,10 @@ This document describes version 0.32 of Complete::Util (from Perl distribution C
 
 =head2 arrayify_answer(%args) -> array
 
-{en_US Make sure we return completion answer in array form}.
+Make sure we return completion answer in array form.
 
-{en_US 
 This is the reverse of C<hashify_answer>. It accepts a hash or an array. If it
 receives a hash, will return its C<words> key.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -573,8 +571,6 @@ Arguments ('*' denotes required arguments):
 
 =item * B<arg>* => I<array|hash>
 
-{en_US }.
-
 =back
 
 Return value:  (array)
@@ -582,9 +578,8 @@ Return value:  (array)
 
 =head2 combine_answers($answers, ...) -> hash
 
-{en_US Given two or more answers, combine them into one}.
+Given two or more answers, combine them into one.
 
-{en_US 
 This function is useful if you want to provide a completion answer that is
 gathered from multiple sources. For example, say you are providing completion
 for the Perl tool C<cpanm>, which accepts a filename (a tarball like C<*.tar.gz>),
@@ -597,7 +592,6 @@ a directory, or a module name. You can do something like this:
 
 If a completion answer has a metadata C<final> set to true, then that answer is
 used as the final answer without any combining with the other answers.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -610,20 +604,16 @@ Arguments ('*' denotes required arguments):
 Return value:  (hash)
 
 
-{en_US 
 Return a combined completion answer. Words from each input answer will be
 combined, order preserved and duplicates removed. The other keys from each
 answer will be merged.
-}
 
 
 =head2 complete_array_elem(%args) -> array
 
-{en_US Complete from array}.
+Complete from array.
 
-{en_US 
 Will sort the resulting completion list, so you don't have to presort the array.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -644,12 +634,10 @@ Return value:  (array)
 
 =head2 complete_env(%args) -> array
 
-{en_US Complete from environment variables}.
+Complete from environment variables.
 
-{en_US 
 On Windows, environment variable names are all converted to uppercase. You can
 use case-insensitive option (C<ci>) to match against original casing.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -666,7 +654,7 @@ Return value:  (array)
 
 =head2 complete_file(%args) -> array
 
-{en_US Complete file and directory from local filesystem}.
+Complete file and directory from local filesystem.
 
 Arguments ('*' denotes required arguments):
 
@@ -674,16 +662,14 @@ Arguments ('*' denotes required arguments):
 
 =item * B<allow_dot> => I<bool> (default: 1)
 
-{en_US If turned off, will not allow "." or ".." in path}.
+If turned off, will not allow "." or ".." in path.
 
-{en_US 
 This is most useful when combined with C<starting_path> option to prevent user
 going up/outside the starting path.
-}
 
 =item * B<ci> => I<bool>
 
-{en_US Case-insensitive matching}.
+Case-insensitive matching.
 
 =item * B<dig_leaf> => I<bool>
 
@@ -691,19 +677,16 @@ going up/outside the starting path.
 
 =item * B<file_regex_filter> => I<re>
 
-{en_US Filter shortcut for file regex}.
+Filter shortcut for file regex.
 
-{en_US 
 This is a shortcut for constructing a filter. So instead of using C<filter>, you
 use this option. This will construct a filter of including only directories or
 regular files, and the file must match a regex pattern. This use-case is common.
-}
 
 =item * B<filter> => I<str|code>
 
-{en_US Only return items matching this filter}.
+Only return items matching this filter.
 
-{en_US 
 Filter can either be a string or a code.
 
 For string filter, you can specify a pipe-separated groups of sequences of these
@@ -716,7 +699,6 @@ files or writable directories.
 For code filter, you supply a coderef. The coderef will be called for each item
 with these arguments: C<$name>. It should return true if it wants the item to be
 included.
-}
 
 =item * B<handle_tilde> => I<bool> (default: 1)
 
@@ -733,7 +715,7 @@ Return value:  (array)
 
 =head2 complete_hash_key(%args) -> array
 
-{en_US Complete from hash keys}.
+Complete from hash keys.
 
 Arguments ('*' denotes required arguments):
 
@@ -752,11 +734,9 @@ Return value:  (array)
 
 =head2 complete_program(%args) -> array
 
-{en_US Complete program name found in PATH}.
+Complete program name found in PATH.
 
-{en_US 
 Windows is supported, on Windows PATH will be split using /;/ instead of /:/.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -773,15 +753,13 @@ Return value:  (array)
 
 =head2 hashify_answer(%args) -> hash
 
-{en_US Make sure we return completion answer in hash form}.
+Make sure we return completion answer in hash form.
 
-{en_US 
 This function accepts a hash or an array. If it receives an array, will convert
 the array into `{words=>$ary}' first to make sure the completion answer is in
 hash form.
 
 Then will add keys from C<meta> to the hash.
-}
 
 Arguments ('*' denotes required arguments):
 
@@ -789,11 +767,9 @@ Arguments ('*' denotes required arguments):
 
 =item * B<arg>* => I<array|hash>
 
-{en_US }.
-
 =item * B<meta> => I<hash>
 
-{en_US Metadata (extra keys) for the hash}.
+Metadata (extra keys) for the hash.
 
 =back
 
